@@ -43,13 +43,14 @@ a batch and provided to your view's implementation.
 
 from urlparse import urljoin
 from os import path
+import logging
 import re
 
 from django import http
+from django.conf import settings
 from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.utils.http import urlquote
-from django.contrib.auth.decorators import login_required
 from django.contrib.syndication.feeds import Feed
 from django.utils.feedgenerator import Atom1Feed
 
@@ -267,12 +268,28 @@ class GenericView(http.HttpResponse):
         if more_context:
             self.context.push()
             self.context.update(more_context)
+        if self.context.get('mobile'):
+            template = ('mobile/' + template, template)
         results = render_to_response(template, context_instance=self.context, **kwargs)
         if more_context:
             self.context.pop()
         return results
 
 
+class _PlainUserWarningProxy(object):
+
+    __slots__ = ('delegate',)
+
+    def __init__(self, delegate):
+        self.delegate = delegate
+
+    def __getattr__(self, key):
+        try:
+            return getattr(self.delegate, key)
+        finally:
+            logging.getLogger(__name__).warning('Template used "user" instead of "typepad_user"')
+
+
 class TypePadView(GenericView):
 
     """
@@ -348,9 +365,13 @@ class TypePadView(GenericView):
         otherwise, returns the Django AnonymousUser. Replaces any authentication
         middleware.
         """
-        from django.contrib.auth import get_user
-        request.user = get_user(request)
-        self.context.update({'user': request.user, 'request': request})
+        from typepadapp.auth import get_user
+        request.typepad_user = get_user(request)
+        self.context.update({
+            'user': _PlainUserWarningProxy(request.typepad_user),
+            'typepad_user': request.typepad_user,
+            'request': request,
+        })
 
     def select_from_typepad(self, request, *args, **kwargs):
         """
@@ -387,12 +408,14 @@ class TypePadView(GenericView):
         if not allowed:
             return allowed, response
         if self.login_required or self.admin_required:
-            response = login_required(lambda r: False)(request)
-            if response:
-                return False, response
+            tpuser = request.typepad_user
+            if not tpuser.is_authenticated():
+                this_url = urlquote(request.get_full_path())
+                return False, http.HttpResponseRedirect('%s?%s=%s'
+                    % (settings.LOGIN_URL, 'next', this_url))
             if self.admin_required:
                 # additionally, user must be an admin
-                if not request.user.is_superuser:
+                if not tpuser.is_superuser:
                     # pretend this url doesn't exist?
                     raise http.Http404
         return True, None
@@ -428,7 +451,10 @@ class TypePadView(GenericView):
             return response
 
         self.select_from_typepad(request, *args, **kwargs)
-        typepad.client.complete_batch()
+        try:
+            typepad.client.complete_batch()
+        except typepad.TypePadObject.NotFound:
+            raise http.Http404
 
         # Page parameter assignment
         if self.paginate_by and self.object_list is not None:
@@ -544,7 +570,10 @@ class TypePadFeed(Feed):
     def get_object(self, *args, **kwargs):
         typepad.client.batch_request()
         self.select_from_typepad(*args, **kwargs)
-        typepad.client.complete_batch()
+        try:
+            typepad.client.complete_batch()
+        except typepad.TypePadObject.NotFound:
+            raise http.Http404
         return getattr(self, 'object', None)
 
     def feed_extra_kwargs(self, obj):
